%global srcname interceptor-api

Name:           jakarta-interceptors
Version:        2.0.0
Release:        %mkrel 1
Group:          Development/Java
Summary:        Jakarta Interceptors
License:        EPL-2.0 or GPLv2 with exceptions

%global upstream_version %{version}-RELEASE

URL:            https://github.com/eclipse-ee4j/interceptor-api
Source0:        %{url}/archive/%{upstream_version}/%{srcname}-%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  maven-local
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.glassfish.build:spec-version-maven-plugin)

# package renamed in fedora 33, remove in fedora 35
Provides:       geronimo-interceptor = %{version}-%{release}
Obsoletes:      geronimo-interceptor < 1.0.1-25

%description
Jakarta Interceptors defines a means of interposing on business method
invocations and specific events—such as lifecycle events and timeout
events—that occur on instances of Jakarta EE components and other
managed classes.


%package javadoc
Summary:        Javadoc for %{name}

# package renamed in fedora 33, remove in fedora 35
Provides:       geronimo-interceptor-javadoc = %{version}-%{release}
Obsoletes:      geronimo-interceptor-javadoc < 1.0.1-25

%description javadoc
API documentation for %{name}.


%prep
%autosetup -n %{srcname}-%{upstream_version} -p1

# remove unnecessary dependencies on parent POM
%pom_remove_parent . api

# do not install useless parent POM
%mvn_package :interceptor-api-parent __noinstall

# do not build specification documentation
%pom_disable_module spec

# remove unnecessary maven plugins
%pom_remove_plugin :maven-enforcer-plugin api .
%pom_remove_plugin :maven-javadoc-plugin api
%pom_remove_plugin :maven-source-plugin api

# disable spec verification (fails because spec-version-maven-plugin is too old)
%pom_xpath_remove 'pom:goal[text()="check-module"]' api

# provide javax.interceptor packages in addition to jakarta.interceptor
cp -pr api/src/main/java/jakarta api/src/main/java/javax
sed -i -e 's/jakarta\./javax./g' $(find api/src/main/java/javax -name *.java)

# add compatibility alias for old maven artifact coordinates
%mvn_alias :jakarta.interceptor-api \
    org.apache.geronimo.specs:geronimo-interceptor_1.1_spec \
    org.apache.geronimo.specs:geronimo-interceptor_3.0_spec

# add compatibility symlink for old classpath
%mvn_file : %{name}/jakarta.interceptor-api geronimo-interceptor


%build
%mvn_build


%install
%mvn_install


%files -f .mfiles
%license LICENSE.md NOTICE.md
%doc README.md

%files javadoc -f .mfiles-javadoc
%license LICENSE.md NOTICE.md



%changelog
* Fri Sep 04 2020 daviddavid <daviddavid> 2.0.0-1.mga8
+ Revision: 1622022
- Update to 2.0.0
- package renamed to jakarta-interceptors

* Tue Feb 11 2020 umeabot <umeabot> 1.0.1-18.mga8
+ Revision: 1489828
- Mageia 8 Mass Rebuild

* Tue Sep 18 2018 umeabot <umeabot> 1.0.1-17.mga7
+ Revision: 1261206
- Mageia 7 Mass Rebuild

* Wed Mar 02 2016 neoclust <neoclust> 1.0.1-16.mga6
+ Revision: 981826
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 1.0.1-15.mga6
+ Revision: 976276
- First rebuild of the java stack
- sync package geronimo-interceptor with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.0.1-11.mga5
+ Revision: 746749
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Fri Jan 03 2014 dmorgan <dmorgan> 1.0.1-9.mga4
+ Revision: 564119
- Build with xmvn

* Thu Dec 19 2013 dmorgan <dmorgan> 1.0.1-8.mga4
+ Revision: 558803
- Build with maven-local
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 1.0.1-6.mga3
+ Revision: 351433
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Sep 10 2012 dmorgan <dmorgan> 1.0.1-5.mga3
+ Revision: 291766
- Build with maven3

* Tue Jul 19 2011 dmorgan <dmorgan> 1.0.1-4.mga2
+ Revision: 126312
- imported package geronimo-interceptor

